==> t_chain_payment_sdk-1.0.1.tar.gz: example/lib/screen/pos_qr_screen.dart <==
import 'package:example/data/pay_result_route_data.dart';
import 'package:example/router/screen_router.dart';
import 'package:example/utils/input_formatter.dart';
import 'package:example/utils/utility.dart';
import 'package:flutter/material.dart';
import 'package:t_chain_payment_sdk/t_chain_payment_sdk.dart';

class PosQrScreen extends StatefulWidget {
  const PosQrScreen({Key? key}) : super(key: key);

  @override
  State<PosQrScreen> createState() => _PosQrScreenState();
}

class _PosQrScreenState extends State<PosQrScreen> {
  final TextEditingController _amountController = TextEditingController();

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    _amountController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: const Text('POS QR')),
      body: SafeArea(
        child: Padding(
          padding: const EdgeInsets.all(24),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              TextField(
                controller: _amountController,
                decoration: InputDecoration(
                  labelText: 'Amount',
                  prefix: Padding(
                    padding: const EdgeInsets.only(right: 10),
                    child: Text(TChainPaymentCurrency.idr.shortName),
                  ),
                  floatingLabelBehavior: FloatingLabelBehavior.auto,
                ),
                keyboardType:
                    const TextInputType.numberWithOptions(decimal: true),
                inputFormatters: InputFormatter.positiveNumberAndZero(),
                onEditingComplete: () => {FocusScope.of(context).unfocus()},
              ),
              const SizedBox(height: 12),
              ElevatedButton(
                onPressed: _onShowQrCode,
                child: const Text('Show QR'),
              ),
            ],
          ),
        ),
      ),
    );
  }

  _onShowQrCode() {
    final amount = double.tryParse(_amountController.text);
    if (amount == null) return;

    // For simplicity, the notes - unique id is generated on the local, but you should create the order on your server-side
    final notes = Utility.generateID();

    Navigator.of(context).pushNamed(
      ScreenRouter.payResult,
      arguments: PayResultRouteData(
        notes: notes,
        amount: amount,
        useQRCode: true,
      ),
    );
  }
}

==> t_chain_payment_sdk-2.0.0.tar.gz: example/lib/screen/pos_qr_screen.dart <==
import 'package:example/data/pay_result_route_data.dart';
import 'package:example/router/screen_router.dart';
import 'package:example/utils/utility.dart';
import 'package:example/widgets/deposit_widget.dart';
import 'package:flutter/material.dart';
import 'package:t_chain_payment_sdk/t_chain_payment_sdk.dart';

class PosQrScreen extends StatefulWidget {
  const PosQrScreen({Key? key}) : super(key: key);

  @override
  State<PosQrScreen> createState() => _PosQrScreenState();
}

class _PosQrScreenState extends State<PosQrScreen> {
  final TextEditingController _amountController = TextEditingController();
  Currency _currency = Currency.usd;

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    _amountController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: const Text('POS QR')),
      body: SafeArea(
        child: Padding(
          padding: const EdgeInsets.all(24),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              DepositWidget(
                amountController: _amountController,
                currency: _currency,
                onCurrencyChanged: (value) {
                  setState(() {
                    _currency = value;
                  });
                },
              ),
              const SizedBox(height: 12),
              ElevatedButton(
                key: const Key('btnShowQr'),
                onPressed: _onShowQrCode,
                child: const Text('Show QR'),
              ),
            ],
          ),
        ),
      ),
    );
  }

  _onShowQrCode() {
    final amount = double.tryParse(_amountController.text);
    if (amount == null) return;

    // For simplicity, the notes - unique id is generated on the local, but you should create the order on your server-side
    final notes = Utility.generateID();

    Navigator.of(context).pushNamed(
      ScreenRouter.payResult,
      arguments: PayResultRouteData(
        notes: notes,
        amount: amount,
        currency: _currency,
        useQRCode: true,
      ),
    );
  }
}
